import { Stack, Heading, Text, Box, Flex } from '@chakra-ui/react'

import ReactMarkdown from 'react-markdown'
import ResponsiveImage from '../components/ResponsiveImage'
import SEO from '../components/SEO'

import {
  getAbout,
  getTeamMembersWithImages,
  IAbout,
  ITeamMemberWithImage,
  login,
} from '../lib/api'

const Team: React.FC<{
  data: { about: IAbout; teamMembers: ITeamMemberWithImage[] }
}> = ({ data }) => {
  const { about, teamMembers } = data
  return (
    <>
      <SEO title="work" />
      <Box w={['100%', '100%', '1220px']} pt="2rem" px="1rem" mx="auto">
        <Flex wrap="wrap">
          <Box w="50%" pr="3rem">
            <Heading fontSize={['3xl', '3xl', '7xl']} mb="3rem">
              About y cosas que hacemos ;)
            </Heading>
          </Box>
          <Box w="50%" pt="6rem">
            <Text
              as={ReactMarkdown}
              fontWeight="300"
              lineHeight="1.9"
              pb="2rem"
              sx={{ p: { display: 'block', pb: '2rem' } }}
            >
              {about.texto_about}
            </Text>
          </Box>
        </Flex>
      </Box>
    </>
  )
}

export default Team

export async function getStaticProps() {
  await login()

  const about = await getAbout()
  const teamMembers = await getTeamMembersWithImages()

  return { props: { data: { about: about.data, teamMembers } } }
}
